@@ -64,6 +64,8 @@ new EventsRuleToLambda(scope: Construct, id: string, props: EventsRuleToLambdaPr
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
 |existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
+|existingEventBusInterface?|[`events.IEventBus`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.IEventBus.html)| Optional user-provided custom EventBus for construct to use. Providing both this and `eventBusProps` results an error.|
+|eventBusProps?|[`events.EventBusProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.EventBusProps.html)|Optional user-provided properties to override the default properties when creating a custom EventBus. Setting this value to `{}` will create a custom EventBus using all default properties. If neither this nor `existingEventBusInterface` is provided the construct will use the `default` EventBus. Providing both this and `existingEventBusInterface` results an error.|
 |lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |eventRuleProps|[`events.RuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.RuleProps.html)|User provided eventRuleProps to override the defaults|
 
@@ -71,6 +73,7 @@ new EventsRuleToLambda(scope: Construct, id: string, props: EventsRuleToLambdaPr
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
+|eventBus?|[`events.IEventBus`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.IEventBus.html)|Returns the instance of events.IEventBus used by the construct|
 |eventsRule|[`events.Rule`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.Rule.html)|Returns an instance of events.Rule created by the construct|
 |lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of lambda.Function created by the construct|
 
@@ -88,8 +91,7 @@ Out of the box implementation of the Construct without any override will set the
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
 * Enable X-Ray Tracing
 * Set Environment Variables
-
-  * AWS_NODEJS_CONNECTION_REUSE_ENABLED (for Node 10.x and higher functions)
+* AWS_NODEJS_CONNECTION_REUSE_ENABLED (for Node 10.x and higher functions)
 
 ## Architecture
 
@@ -128,6 +130,8 @@ class EventsRuleToLambda(
         id: builtins.str,
         *,
         event_rule_props: aws_cdk.aws_events.RuleProps,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
@@ -135,6 +139,8 @@ class EventsRuleToLambda(
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
+        :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
+        :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
@@ -143,6 +149,8 @@ class EventsRuleToLambda(
         '''
         props = EventsRuleToLambdaProps(
             event_rule_props=event_rule_props,
+            event_bus_props=event_bus_props,
+            existing_event_bus_interface=existing_event_bus_interface,
             existing_lambda_obj=existing_lambda_obj,
             lambda_function_props=lambda_function_props,
         )
@@ -159,12 +167,19 @@ class EventsRuleToLambda(
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="eventBus")
+    def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
+        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-events-rule-lambda.EventsRuleToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
         "event_rule_props": "eventRuleProps",
+        "event_bus_props": "eventBusProps",
+        "existing_event_bus_interface": "existingEventBusInterface",
         "existing_lambda_obj": "existingLambdaObj",
         "lambda_function_props": "lambdaFunctionProps",
     },
@@ -174,11 +189,15 @@ class EventsRuleToLambdaProps:
         self,
         *,
         event_rule_props: aws_cdk.aws_events.RuleProps,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
+        :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
+        :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
@@ -186,11 +205,17 @@ class EventsRuleToLambdaProps:
         '''
         if isinstance(event_rule_props, dict):
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+        if isinstance(event_bus_props, dict):
+            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
         }
+        if event_bus_props is not None:
+            self._values["event_bus_props"] = event_bus_props
+        if existing_event_bus_interface is not None:
+            self._values["existing_event_bus_interface"] = existing_event_bus_interface
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
         if lambda_function_props is not None:
@@ -206,6 +231,26 @@ class EventsRuleToLambdaProps:
         assert result is not None, "Required property 'event_rule_props' is missing"
         return typing.cast(aws_cdk.aws_events.RuleProps, result)
 
+    @builtins.property
+    def event_bus_props(self) -> typing.Optional[aws_cdk.aws_events.EventBusProps]:
+        '''A new custom EventBus is created with provided props.
+
+        :default: - None
+        '''
+        result = self._values.get("event_bus_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_events.EventBusProps], result)
+
+    @builtins.property
+    def existing_event_bus_interface(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
+        '''Existing instance of a custom EventBus.
+
+        :default: - None
+        '''
+        result = self._values.get("existing_event_bus_interface")
+        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], result)
+
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
         '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
